API Reference
=============

subpackages
-----------

.. toctree::

   cooltools.lib
   cooltools.io

cooltools.balance module
------------------------

.. automodule:: cooltools.balance
   :members:
   :undoc-members:
   :show-inheritance:

.. cooltools.contrast module
.. -------------------------

.. .. automodule:: cooltools.contrast
..    :members:
..    :undoc-members:
..    :show-inheritance:

cooltools.coverage module
-------------------------

.. automodule:: cooltools.coverage
   :members:
   :undoc-members:
   :show-inheritance:

cooltools.directionality module
-------------------------------

.. automodule:: cooltools.directionality
   :members:
   :undoc-members:
   :show-inheritance:

cooltools.dotfinder module
--------------------------

.. automodule:: cooltools.dotfinder
   :members:
   :undoc-members:
   :show-inheritance:

cooltools.eigdecomp module
--------------------------

.. automodule:: cooltools.eigdecomp
   :members:
   :undoc-members:
   :show-inheritance:

cooltools.expected module
-------------------------

.. automodule:: cooltools.expected
   :members:
   :undoc-members:
   :show-inheritance:

cooltools.insulation module
---------------------------

.. automodule:: cooltools.insulation
   :members:
   :undoc-members:
   :show-inheritance:

cooltools.saddle module
-----------------------

.. automodule:: cooltools.saddle
   :members:
   :undoc-members:
   :show-inheritance:

cooltools.sample module
-----------------------

.. automodule:: cooltools.sample
   :members:
   :undoc-members:
   :show-inheritance:

cooltools.snipping module
-------------------------

.. automodule:: cooltools.snipping
   :members:
   :undoc-members:
   :show-inheritance:
